TypeDef
=======

.. currentmodule:: pyobo

.. autoclass:: TypeDef
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TypeDef.comment
      ~TypeDef.created_by
      ~TypeDef.definition
      ~TypeDef.domain
      ~TypeDef.holds_over_chain
      ~TypeDef.inverse
      ~TypeDef.is_metadata_tag
      ~TypeDef.is_symmetric
      ~TypeDef.is_transitive
      ~TypeDef.namespace
      ~TypeDef.range

   .. rubric:: Methods Summary

   .. autosummary::

      ~TypeDef.from_curie
      ~TypeDef.from_triple
      ~TypeDef.iterate_obo_lines

   .. rubric:: Attributes Documentation

   .. autoattribute:: comment
   .. autoattribute:: created_by
   .. autoattribute:: definition
   .. autoattribute:: domain
   .. autoattribute:: holds_over_chain
   .. autoattribute:: inverse
   .. autoattribute:: is_metadata_tag
   .. autoattribute:: is_symmetric
   .. autoattribute:: is_transitive
   .. autoattribute:: namespace
   .. autoattribute:: range

   .. rubric:: Methods Documentation

   .. automethod:: from_curie
   .. automethod:: from_triple
   .. automethod:: iterate_obo_lines
